Package - Nautobot Design Builder Documentation

Skip to content

# Package

## `nautobot_design_builder`

Plugin declaration for nautobot_design_builder.

### `NautobotDesignBuilderConfig`

Bases: `NautobotAppConfig`

Plugin configuration for the nautobot_design_builder plugin.

Source code in `nautobot_design_builder/__init__.py`

    14
    15
    16
    17
    18
    19
    20
    21
    22
    23
    24
    25
    26
    27
    28
    29
    30
    31
    32
    33
    34
    35
    36
    37
    38
    39
    40
    class NautobotDesignBuilderConfig(NautobotAppConfig):
        """Plugin configuration for the nautobot_design_builder plugin."""

        name = "nautobot_design_builder"
        verbose_name = "Nautobot Design Builder"
        version = __version__
        author = "Network to Code, LLC"
        description = "Nautobot app that uses design templates to easily create data objects in Nautobot with minimal input from a user.."
        base_url = "design-builder"
        required_settings = []
        default_settings = {
            "protected_models": [],
            "protected_superuser_bypass": True,
        }
        docs_view_name = "plugins:nautobot_design_builder:docs"
        searchable_models = ["design"]

        def ready(self):
            """Callback after design builder is loaded."""
            super().ready()
            from . import signals  # noqa:F401 pylint:disable=import-outside-toplevel,unused-import,cyclic-import

        # pylint: disable=no-self-argument
        @classproperty
        def context_repository(cls):
            """Retrieve the Git Repository slug that has been configured for the Design Builder."""
            return settings.PLUGINS_CONFIG[cls.name]["context_repository"]

#### `context_repository()`

Retrieve the Git Repository slug that has been configured for the Design Builder.

Source code in `nautobot_design_builder/__init__.py`

    37
    38
    39
    40
    @classproperty
    def context_repository(cls):
        """Retrieve the Git Repository slug that has been configured for the Design Builder."""
        return settings.PLUGINS_CONFIG[cls.name]["context_repository"]

#### `ready()`

Callback after design builder is loaded.

Source code in `nautobot_design_builder/__init__.py`

    31
    32
    33
    34
    def ready(self):
        """Callback after design builder is loaded."""
        super().ready()
        from . import signals  # noqa:F401 pylint:disable=import-outside-toplevel,unused-import,cyclic-import